@@ -31,11 +31,13 @@ $ReceiveEventCodes = {
     1  => 'goes_online',
     2  => 'goes_offline',
     3  => 'change_status',
-    4  => 'change_status',
+    4  => 'change_normal_status',
     6  => 'receive_message',
-    15 => 'new_friend_alert',
+    15 => 'new_buddy_alert',
+    24 => 'conference_invitation',
     75 => 'toggle_typing',
     76 => 'server_is_alive',
+    77 => 'receive_file',
     84 => 'cram_auth_fail',
     85 => 'receive_buddy_list',
     87 => 'challenge_start',
@@ -46,6 +48,7 @@ $ReceiveEventNames = { reverse %$ReceiveEventCodes };
 $SendEventCodes = {
     %$ReceiveEventCodes,
     6  => 'send_message',
+    77 => 'send_file',
     84 => 'challenge_response',
 };
 
@@ -55,7 +58,7 @@ $BodyCodes = {
     0  => 'my_id',
     1  => 'id',
     2  => 'login_nickname',
-    3  => 'new_buddy_name',
+    3  => 'new_buddy_id',
     4  => 'from',
     5  => 'to',
     6  => 'crypt_salt',
@@ -68,7 +71,17 @@ $BodyCodes = {
     15 => 'received_time',
     16 => 'error_message',
     19 => 'status_message',
+    20 => 'download_url',
+    27 => 'filename',
+    28 => 'filesize',
     47 => 'busy_code',
+    49 => 'command_name',	# XXX 'FILEXFER'
+    50 => 'invitation_from',
+    52 => 'invitation_with',	# XXX
+    53 => 'download_filename',
+    54 => 'protocol',		# XXX 'MSG1.0'
+    57 => 'conference_name',
+    58 => 'invitation_message',
     87 => 'buddy_list',
     94 => 'challenge_string',
     96 => 'crypted_response',
